"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var sentry_common_1 = require("./sentry.common");
var application = require("tns-core-modules/application");
var utils = require("tns-core-modules/utils/utils");
var Sentry = (function (_super) {
    __extends(Sentry, _super);
    function Sentry() {
        return _super.call(this) || this;
    }
    Sentry.init = function (dsn) {
        this._init(dsn);
        try {
            io.sentry.Sentry.init(dsn, new io.sentry.android.AndroidSentryClientFactory(utils.ad.getApplicationContext()));
        }
        catch (error) {
            console.log('[Sentry - Android] Exeption on init: ', error);
        }
        application.on(application.uncaughtErrorEvent, function (args) {
            try {
                io.sentry.Sentry.capture(args.android);
            }
            catch (e) {
                console.log('[Sentry - Android] Exeption on capture: ', e);
            }
        });
    };
    Sentry.captureMessage = function (message, options) {
        this._captureMessage(message, options);
    };
    Sentry.captureException = function (exception, options) {
        this._captureException(exception, options);
    };
    Sentry.captureBreadcrumb = function (breadcrumb) {
        this._captureBreadcrumb(breadcrumb);
        var breadcrumbNative = new io.sentry.event.BreadcrumbBuilder()
            .setCategory(breadcrumb.category)
            .setMessage(breadcrumb.message)
            .setData(breadcrumb.data);
        var sentryClient = io.sentry.Sentry.getStoredClient();
        sentryClient.getContext().recordBreadcrumb(breadcrumbNative.build());
    };
    Sentry.setContextUser = function (user) {
        this._setUser(user);
        var userNative = new io.sentry.event.UserBuilder()
            .setEmail(user.email)
            .setUsername(user.username)
            .build();
        var sentryClient = io.sentry.Sentry.getStoredClient();
        sentryClient.getContext().setUser(userNative);
    };
    Sentry.setContextTags = function (tags) {
        this._setTags(tags);
        var sentryClient = io.sentry.Sentry.getStoredClient();
        Object.keys(tags).forEach(function (key) {
            sentryClient.addTag(key, tags[key]);
        });
    };
    Sentry.setContextExtra = function (extra) {
        this._setExtra(extra);
        var sentryClient = io.sentry.Sentry.getStoredClient();
        Object.keys(extra).forEach(function (key) {
            sentryClient.addExtra(key, extra[key]);
        });
    };
    Sentry.clearContext = function () {
        this._clearContext();
        var sentryClient = io.sentry.Sentry.getStoredClient();
        sentryClient.clearContext();
    };
    Sentry.onBeforeSend = function (callback) {
        var sentryClient = io.sentry.Sentry.getStoredClient();
        var shouldSend = new io.sentry.event.helper.ShouldSendEventCallback({
            shouldSend: function (event) {
                console.log('vou enviar no android');
                return callback(event);
            }
        });
        sentryClient.addShouldSendEventCallback(shouldSend);
    };
    return Sentry;
}(sentry_common_1.Common));
exports.Sentry = Sentry;
//# sourceMappingURL=sentry.android.js.map